package com.example.pda.model

import android.content.Context
import android.content.SharedPreferences
import kotlin.reflect.KProperty


object AppPrefs {
    private lateinit var prefs: SharedPreferences

    fun init(context: Context) {
        prefs = context.getSharedPreferences("app_prefs", Context.MODE_PRIVATE)
    }

    // 使用 Lambda 延迟访问 prefs
    var username by StringPreference({ prefs }, "username", "")

    var token by StringPreference({ prefs }, "token", "")
    var ip_server by StringPreference({ prefs }, "ip_server", "")
    var base_url by StringPreference({ prefs }, "base_url", "")
    var rememberMe by BooleanPreference({ prefs }, "remember_me", false)
    var isDarkMode by BooleanPreference({ prefs }, "dark_mode", false)
    var islogin by BooleanPreference({ prefs }, "islogin", false)

    // 修改委托类，接受 Lambda 提供 prefs
    private class StringPreference(
        private val prefsProvider: () -> SharedPreferences, // 通过 Lambda 获取 prefs
        private val key: String,
        private val defaultValue: String
    ) {
        operator fun getValue(thisRef: Any?, property: KProperty<*>): String {
            return prefsProvider().getString(key, defaultValue) ?: defaultValue
        }

        operator fun setValue(thisRef: Any?, property: KProperty<*>, value: String) {
            prefsProvider().edit { putString(key, value) }
        }
    }

    private class BooleanPreference(
        private val prefsProvider: () -> SharedPreferences, // 通过 Lambda 获取 prefs
        private val key: String,
        private val defaultValue: Boolean
    ) {
        operator fun getValue(thisRef: Any?, property: KProperty<*>): Boolean {
            return prefsProvider().getBoolean(key, defaultValue)
        }

        operator fun setValue(thisRef: Any?, property: KProperty<*>, value: Boolean) {
            prefsProvider().edit { putBoolean(key, value) }
        }
    }

    // 清空数据（退出登录时调用）
    fun clearAll() {
        prefs.edit { clear() }
    }

    // 扩展函数：简化 SharedPreferences.Editor 操作
    private inline fun SharedPreferences.edit(action: SharedPreferences.Editor.() -> Unit) {
        val editor = edit()
        action(editor)
        editor.apply()
    }
}