package com.example.pda.network

import okhttp3.Interceptor
import okhttp3.OkHttpClient
import okhttp3.logging.HttpLoggingInterceptor
import java.util.concurrent.TimeUnit

object HttpClient {
    // 动态 Token 存储（volatile 保证多线程可见性）
    @Volatile
    var token: String? = null

    // 认证拦截器（私有保证内部管理）
    private val authInterceptor = Interceptor { chain ->
        chain.request().newBuilder().apply {
            // 仅在 token 存在时添加 Header
            token?.let { addHeader("token", it) }
        }.build().let(chain::proceed)
    }

    // 带动态 Header 的 OkHttpClient
    val instance: OkHttpClient by lazy {
        OkHttpClient.Builder()
            .connectTimeout(1, TimeUnit.SECONDS)
            .readTimeout(1, TimeUnit.SECONDS)
            .writeTimeout(1, TimeUnit.SECONDS)
            .addInterceptor(authInterceptor) // 先添加认证拦截器
            .addInterceptor(HttpLoggingInterceptor().apply {
                level = HttpLoggingInterceptor.Level.BODY // 后添加日志拦截器
            })
            .build()
    }
}