package com.example.pda.ui

import androidx.compose.foundation.layout.*
import androidx.compose.material3.*
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.foundation.background
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp

import com.example.pda.R
import com.example.pda.network.HttpClient

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun MainScreen(
    onInventoryScan: () -> Unit,
    onShelfScan: () -> Unit,
    onSetScreen: () -> Unit
) {
    LaunchedEffect(Unit) {
        // 在登录成功后调用
        HttpClient.token = "PDA1"
    }
    Scaffold(
        topBar = {
            TopAppBar(
                title = {
                    Row(verticalAlignment = Alignment.CenterVertically) {
                        Icon(
                            painter = painterResource(id = R.drawable.logo),
                            contentDescription = "PDA Logo",
                            modifier = Modifier.size(40.dp),
                            tint = MaterialTheme.colorScheme.surfaceTint
                        )
                        Spacer(Modifier.width(8.dp))
                        Text("信泰PDA扫描系统")
                    }
                },
                colors = TopAppBarDefaults.topAppBarColors(
                    containerColor = Color(0xFFBCD0C5), // 自定义颜色
                    titleContentColor = MaterialTheme.colorScheme.onPrimary,
                    actionIconContentColor = MaterialTheme.colorScheme.onPrimary
                ),
                actions = {
                    IconButton(onClick = { onSetScreen() }) {
                        Icon(
                            painter = painterResource(id = R.drawable.ic_settings),
                            contentDescription = "Settings",
                            tint = MaterialTheme.colorScheme.onSurface
                        )
                    }
                },
            )
        }
    ) { innerPadding ->
        Box(
            modifier = Modifier
                .padding(innerPadding)
                .fillMaxSize()
                .background(Color(0xFFE6E6EB)),
            contentAlignment = Alignment.Center
             
            
        ) {
            
            Column(
                horizontalAlignment = Alignment.CenterHorizontally,
                verticalArrangement = Arrangement.spacedBy(60.dp)
            ) {
                ExtendedFloatingActionButton(
                    onClick = onInventoryScan,
                    modifier = Modifier.size(220.dp, 70.dp),
                    containerColor = Color(0xFFFDECD0), 
                    icon = {
                        Icon(
                            painter = painterResource(id = R.drawable.ic_scan),
                            contentDescription = "入库扫描"
                        )
                    },
                    text = { 
                        Text(
                            text = "入库扫描",
                            fontSize = 18.sp,
                            color = MaterialTheme.colorScheme.onSurface
                            ) 
                        }
                )
                ExtendedFloatingActionButton(
                    onClick = onShelfScan,
                    modifier = Modifier.size(220.dp, 70.dp),
                    containerColor = Color(0xFF91BFBF),
                    icon = {
                        Icon(
                            painter = painterResource(id = R.drawable.ic_scan),
                            contentDescription = "托盘扫描"
                        )
                    },
                    text = {
                        Text(
                            text = "托盘扫描",
                            fontSize = 20.sp,
                            color = MaterialTheme.colorScheme.onSurface
                        )
                    }
                )
            }
            
        }
    }
}